/*
Experimental example on how OSC could be used to control Resolume Avenue 3
It's a very simple version of Pong whithout score
The direction and speed of the ball control the direction and pitch of an audio clip played in Resolume.
Load a audio clip in channel 1 of layer 1 set it to play and turn up the volume a bit.
Start playing this sketch and see/hear what happends.
*/


// start OSC config
import oscP5.*;
import netP5.*;
  
/*portToListenTo, port we are listening on, this should be the same as
the outgoing port of TouchOsc on your iphone
*/
int portToListenTo = 7001; 
/*portToSendTo, port we are sending to, this should be the same as
the incomning port of Resolume 3, default it is set to 7000, so you wouldn't need to change it.
*/
int portToSendTo = 7000;
/*ipAddressToSendTo, ip address of the computer we are sending messages to (where Resolume 3 runs)
*/
String ipAddressToSendTo = "localhost";

OscP5 oscP5;
NetAddress myRemoteLocation;
OscBundle myBundle;
OscMessage myMessage;
//end OSC config



//paddle
float pX; //paddle x position
float pY;
float pSizeX;
float pSizeY;
float pSpeed;

//ball
float bX; //paddle x position
float bY;
float bSize;
float bXSpeed;
float bYSpeed;
int bVDirection;
int bHDirection;

//
int margin = 16;
int wait = 100;

boolean speedChanged = true;
boolean directionChanged = true;

void setup() 
{
  frameRate(30);
  size(640, 480); 
  noStroke();
  rectMode(CENTER);
  initPaddle();
  initBall();
  
  oscP5 = new OscP5(this,portToListenTo);
  myRemoteLocation = new NetAddress(ipAddressToSendTo, portToSendTo);  
  myBundle = new OscBundle();
  myMessage = new OscMessage("/"); 
  
}

void draw() 
{   
  background(51);//200, 200, 200, 200); 
  fill(255);
  
  drawPong();
  
  if (directionChanged) {
    myMessage.setAddrPattern("/layer1/clip1/audio/position/direction");
    myMessage.add(bHDirection);
    myBundle.add(myMessage);
    myMessage.clear();
  }
  
  if (speedChanged) {
    myMessage.setAddrPattern("/layer1/clip1/audio/pitch/values");
    float newSpeed = bXSpeed / 15.0;
    print(newSpeed);
    myMessage.add( newSpeed );
    myBundle.add(myMessage);
    myMessage.clear(); 
  } 
  
  if (directionChanged || speedChanged) {
    directionChanged = false;
    speedChanged = false;
    oscP5.send(myBundle, myRemoteLocation); 
    myBundle.clear();  
  }
}


void drawPong()
{
  
  if(keyPressed) {
    if (keyCode == UP) {
      pY -= pSpeed;
    } else if (keyCode == DOWN) {
      pY += pSpeed;
    } 
  }


  if (wait > 0) {
    wait--;
  } else {
 

  
    if (bHDirection == 0) {
      bX += bXSpeed;
      if (bX > width - margin) {
        //balls hit back wall
        //invert direction and increase speed a bit
        bHDirection = 1;
        bXSpeed += 0.5;
        if (bXSpeed > 15) 
          bXSpeed = 15;
        speedChanged = true;
        directionChanged = true;
      }
    } else {
      if ( paddleHitsBall() ) {
          bHDirection = 0;
          bX += bXSpeed;
          bXSpeed += 0.5;
          if (bXSpeed > 15) 
            bXSpeed = 15;
          speedChanged = true;
          directionChanged = true;
      } else {    
        if (bX < margin)
          bHDirection = 0;
        bX -= bXSpeed;
      }    
    }
    
    if (bVDirection == 0) {
      bY += bYSpeed;
      if (bY > height - margin)
        bVDirection = 1;
    } else {
      if (bY < margin)
        bVDirection = 0;    
      bY -= bYSpeed;    
    }
    
    if (bX < margin) { //you lost
        initBall();
        initPaddle();
        wait = 50;
    }
    
    
  }
  
  ellipse(bX, bY, bSize, bSize);  
    
  rect(pX, pY, pSizeX, pSizeY);  
  
}


void initBall()
{
  //init ball
  bX = width/2;
  bY = height / 2;
  bSize = 16;
  bXSpeed = 5;
  bYSpeed = 3;
  bVDirection = 0;
  bHDirection = 0; 
  speedChanged = true;
  directionChanged = true;
}

void initPaddle()
{
   //init paddle
  pX = 20;
  pY = height / 2;
  pSizeY = height/10;
  pSizeX = 15;
  pSpeed = 5; 
}


boolean paddleHitsBall()
{
  // Test to see if the ball is touching the paddle
  float x1 = pX;
  float y1 = pY-(pSizeY/2);
  float x2 = pX + 15;
  float y2 = pY+(pSizeY/2);
	
  if (bX >= x1 && bX <= x2 && bY >= y1 && bY <= y2)
    return true;
		
  return false;
}

